Crate ark_core

Crate ark_core 

Re-exports

pub use arknote::ArkNote;
pub use boarding_output::BoardingOutput;
pub use script::extract_sequence_from_csv_sig_script;
pub use unilateral_exit::build_anchor_tx;
pub use unilateral_exit::build_unilateral_exit_tree_txids;
pub use unilateral_exit::SelectedUtxo;
pub use unilateral_exit::UtxoCoinSelection;
pub use vtxo::Vtxo;

Modules

arknote
ArkNote: a transferable off-chain value token.
batch
boarding_output
coin_select
conversions
history
intent
script
send
server
Messages exchanged between the client and the Ark server.
unilateral_exit
vhtlc
Virtual Hash Time Lock Contract (VHTLC) implementation for Ark Lightning Swaps.
vtxo

Structs

ArkAddress
Error
ExplorerUtxo
Information a UTXO that may be extracted from an on-chain explorer.
TxGraph
TxGraphChunk
VtxoList

Constants

DEFAULT_DERIVATION_PATH
UNSPENDABLE_KEY
VTXO_CONDITION_KEY
The byte value corresponds to the string “condition”.
VTXO_COSIGNER_PSBT_KEY
The cosigner PKs that sign a VTXO TX input are included in the unknown key-value map field of that input in the VTXO PSBT. Since the unknown field can be used for any purpose, we know that a value is a cosigner PK if the corresponding key starts with this prefix.
VTXO_INPUT_INDEX
VTXO_TAPROOT_KEY
The byte value corresponds to the string “taptree”.
VTXO_TREE_EXPIRY_PSBT_KEY
The byte value corresponds to the string “expiry”.

Traits

ErrorContext
A trait for contextualizing error values.

Functions

anchor_output