ArkNote: a transferable off-chain value token.
An ArkNote encodes a preimage and a value. Anyone who knows the preimage can spend the note by revealing it. This enables simple bearer-token-style transfers.
Structs
- ArkNote
- ArkNote is a bearer token that can be redeemed by revealing its preimage.
Constants
- DEFAULT_
HRP - Default human-readable prefix for ArkNote string encoding.
- FAKE_
VOUT - Fake outpoint vout used for ArkNotes (they don’t correspond to real UTXOs).
- PREIMAGE_
LENGTH - Length of the preimage in bytes.