Module batch

Module batch 

Structs

Delegate
A delegate contains all the information necessary for another party to settle VTXOs on behalf of the owner.
NonceKps
A nonce key pair per batch-tree transaction output that we are a part of in the batch.
OnChainInput
A UTXO that is primed to become a VTXO. Alternatively, the owner of this UTXO may decide to spend it into a vanilla UTXO.

Functions

aggregate_nonces
Compute the aggregated nonce public key for a transaction in the batch-tree.
complete_delegate_forfeit_txs
create_and_sign_forfeit_txs
Build and sign a forfeit transaction per [VtxoInput] to be used in an upcoming commitment transaction.
create_asset_preservation_packet
Complete the delegated forfeit transactions by adding connector inputs and finalizing them.
generate_nonce_tree
Generate a nonce key pair for each batch-tree transaction output that we are a part of in the batch.
prepare_delegate_psbts
Prepare unsigned intent and forfeit PSBTs for delegate.
prepare_delegate_psbts_at
Like prepare_delegate_psbts, but with an explicit valid_at timestamp.
sign_batch_tree_tx
Use own_cosigner_kp to sign each batch-tree transaction output that we are a part of, using our_nonce_kps to provide our share of each aggregate nonce.
sign_commitment_psbt
Sign every input of the commitment_psbt which is in the provided onchain_inputs list.
sign_delegate_psbts
Sign delegate PSBTs.