pub struct Delegate {
pub intent: Intent,
pub forfeit_psbts: Vec<Psbt>,
pub delegate_cosigner_pk: PublicKey,
}Expand description
A delegate contains all the information necessary for another party to settle VTXOs on behalf of the owner.
The owner pre-signs the intent and forfeit transactions, allowing another party to complete the settlement at a later time.
Fields
intent: Intentforfeit_psbts: Vec<Psbt>Partial forfeit transactions signed with SIGHASH_ALL | ANYONECANPAY.
delegate_cosigner_pk: PublicKeyThe cosigner public key of the party who will execute the settlement as the delegate.