pub struct BoardingOutput { /* private fields */ }Implementations
Sourceimpl BoardingOutput
impl BoardingOutput
pub fn new<C>(
secp: &Secp256k1<C>,
server: XOnlyPublicKey,
owner: XOnlyPublicKey,
exit_delay: Sequence,
network: Network,
) -> Result<Self, Error>where
C: Verification,
pub fn address(&self) -> &Address
pub fn owner_pk(&self) -> XOnlyPublicKey
pub fn server_pk(&self) -> XOnlyPublicKey
pub fn script_pubkey(&self) -> ScriptBuf
pub fn forfeit_spend_info(&self) -> (ScriptBuf, ControlBlock)
pub fn exit_spend_info(&self) -> (ScriptBuf, ControlBlock)
pub fn exit_delay(&self) -> Sequence
pub fn output_key(&self) -> TweakedPublicKey
pub fn to_ark_address( &self, network: Network, server: XOnlyPublicKey, ) -> ArkAddress
pub fn tapscripts(&self) -> Vec<ScriptBuf>
Sourcepub fn can_be_claimed_unilaterally_by_owner(
&self,
now: Duration,
confirmation_blocktime: Duration,
confirmations: u64,
) -> bool
pub fn can_be_claimed_unilaterally_by_owner( &self, now: Duration, confirmation_blocktime: Duration, confirmations: u64, ) -> bool
Whether the boarding output can be claimed unilaterally by the owner or not, given the
confirmation_blocktime of the transaction that included this boarding output as an output.