pub struct StoredContract {
pub contract_type: ContractType,
pub contract_version: u32,
pub script_pubkey: ScriptBuf,
pub state: ContractState,
pub created_at: u64,
pub key_index: Option<u32>,
pub data: Value,
}Fields
contract_type: ContractTypecontract_version: u32script_pubkey: ScriptBufstate: ContractStatecreated_at: u64key_index: Option<u32>HD derivation index for contracts generated by an index-based key provider.
Static/custom providers may not expose an index, and imported contracts may not have one.
data: ValueTrait Implementations
Sourceimpl Clone for StoredContract
impl Clone for StoredContract
Sourcefn clone(&self) -> StoredContract
fn clone(&self) -> StoredContract
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoredContract
impl Debug for StoredContract
Sourceimpl<'de> Deserialize<'de> for StoredContract
impl<'de> Deserialize<'de> for StoredContract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StoredContract
Sourceimpl PartialEq for StoredContract
impl PartialEq for StoredContract
Sourcefn eq(&self, other: &StoredContract) -> bool
fn eq(&self, other: &StoredContract) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StoredContract
impl Serialize for StoredContract
impl StructuralPartialEq for StoredContract