pub enum OutgoingTransaction {
Complete(Transaction),
Incomplete(IncompleteOutgoingTransaction),
IncompleteOffboard(IncompleteOffboardTransaction),
}Expand description
An outgoing transaction.
If the transaction is OutgoingTransaction::Complete, it can be used as is. If the
transaction is OutgoingTransaction::Incomplete, you will need to complete it with a
VirtualTxOutPoint. If the transaction is OutgoingTransaction::IncompleteOffboard, you
will need to complete it with confirmation data.
Refer to generate_outgoing_vtxo_transaction_history for more info on how to use this type.
Variants
Complete(Transaction)
Incomplete(IncompleteOutgoingTransaction)
IncompleteOffboard(IncompleteOffboardTransaction)