IncompleteOffboardTransaction

Struct IncompleteOffboardTransaction 

pub struct IncompleteOffboardTransaction { /* private fields */ }
An offboard transaction that is missing confirmation data so that it can be completed.

Use IncompleteOffboardTransaction::finish to complete the transaction with confirmation data from an external source (e.g., esplora).

Implementations

Source

impl IncompleteOffboardTransaction

pub fn commitment_txid(&self) -> Txid

The commitment TXID of this offboard transaction.

Use this value to query an external source (e.g., esplora) for confirmation data.

pub fn finish(self, confirmed_at: Option<i64>) -> Transaction

Transform this incomplete offboard transaction into a Transaction.

Arguments
  • confirmed_at: The confirmation time of the commitment transaction, or None if unconfirmed.