pub enum Output {
Offchain(TxOut),
Onchain(TxOut),
AssetPacket(TxOut),
}Variants
Offchain(TxOut)
An output created when boarding.
Onchain(TxOut)
An output created when offboarding.
AssetPacket(TxOut)
An auxiliary output that should be copied into the target transaction but is neither an offchain VTXO nor an onchain payout.