Module script

Module script 

Structs

InvalidCsvSigScriptError

Functions

arknote_script
A hash-lock script for ArkNotes.
csv_sig_script
A ScriptBuf allowing the owner of pk to spend after locktime_seconds have passed from the time the corresponding output was included in a block.
extract_checksig_pubkeys
Extracts all XOnlyPublicKeys from checksig patterns in the script.
extract_sequence_from_csv_sig_script
multisig_script
A conventional 2-of-2 multisignature ScriptBuf.
tr_script_pubkey
The script pubkey for the Taproot output corresponding to the given TaprootSpendInfo.