csv_sig_script

Function csv_sig_script 

pub fn csv_sig_script(locktime: Sequence, pk: XOnlyPublicKey) -> ScriptBuf
A ScriptBuf allowing the owner of pk to spend after locktime_seconds have passed from the time the corresponding output was included in a block.