extract_checksig_pubkeys

Function extract_checksig_pubkeys 

pub fn extract_checksig_pubkeys(script: &ScriptBuf) -> Vec<XOnlyPublicKey>
Extracts all XOnlyPublicKeys from checksig patterns in the script.

Finds all 32-byte data pushes that are immediately followed by OP_CHECKSIG or OP_CHECKSIGVERIFY opcodes.

Returns an empty vector if no matching keys are found.