pub fn tr_script_pubkey(spend_info: &TaprootSpendInfo) -> ScriptBufExpand description
The script pubkey for the Taproot output corresponding to the given TaprootSpendInfo.
pub fn tr_script_pubkey(spend_info: &TaprootSpendInfo) -> ScriptBufThe script pubkey for the Taproot output corresponding to the given TaprootSpendInfo.