Re-exports
pub use issue_asset::build_self_asset_issuance_transactions;pub use issue_asset::SelfAssetIssuanceTransactions;pub use reissue_asset::build_asset_reissuance_transactions;pub use reissue_asset::AssetReissuanceTransactions;
Modules
Structs
- Offchain
Transactions - Send
Receiver - A receiver for a generic offchain send with optional assets.
- Vtxo
Input - A VTXO to be spent into an unconfirmed VTXO.
Functions
- build_
asset_ burn_ transactions - Build unsigned offchain transactions for burning a specific amount of an asset.
- build_
asset_ send_ transactions - Build unsigned offchain transactions for sending BTC and optional assets to one or more receivers.
- build_
offchain_ transactions - Build unsigned offchain transactions for sending BTC to one or more receivers.
- sign_
ark_ transaction - sign_
checkpoint_ transaction