Module server

Module server 

Messages exchanged between the client and the Ark server.

Structs

ArkTransaction
Asset
An asset carried by a VTXO.
AssetInfo
Metadata about an issued asset, including its control asset reference.
BatchFailed
BatchFinalizationEvent
BatchFinalizedEvent
BatchStartedEvent
CommitmentTransaction
DeprecatedSigner
FeeInfo
Fee information from the server.
FinalizeOffchainTxResponse
GetVtxosRequest
IndexerPage
Info
IntentFeeInfo
Intent fee information.
NoncePks
An aggregate public nonce per shared internal (non-leaf) node in the batch-tree.
PageRequest
Page request for paginated queries.
PartialSigTree
A Musig partial signature per shared internal (non-leaf) node in the batch-tree.
PendingTx
ScheduledSession
StreamStartedEvent
SubmitOffchainTxResponse
SubscriptionEvent
TreeNoncesAggregatedEvent
TreeNoncesEvent
TreeSignatureEvent
TreeSigningStartedEvent
TreeTxEvent
TreeTxNoncePks
A public nonce per public key, where each public key corresponds to a party signing a transaction in the batch-tree.
TxTree
TxTreeNode
VirtualTxOutPoint
VirtualTxsResponse
VtxoChain
VtxoChains

Enums

BatchTreeEventType
ChainedTxType
DeprecatedSignerStatus
Status of a deprecated server signer at a specific point in time.
GetVtxosRequestFilter
GetVtxosRequestReference
Network
ServerSignerStatus
Rotation status for any server signer key known to a client.
StreamEvent
StreamTransactionData
SubscriptionResponse

Constants

SDK_VERSION
Version of this SDK, as rust-sdk/<crate version>.
TARGET_ARKD_VERSION
arkd build version targeted by this SDK.

Functions

parse_fee_amount
Parse a fee amount string as satoshis. Returns Amount::ZERO for empty or missing strings.
parse_sequence_number