pub struct TreeTxNoncePks(pub HashMap<XOnlyPublicKey, PublicNonce>);Expand description
A public nonce per public key, where each public key corresponds to a party signing a transaction in the VTXO tree.
Tuple Fields
0: HashMap<XOnlyPublicKey, PublicNonce>Implementations