finalize_virtual_tx_input

Function finalize_virtual_tx_input 

pub fn finalize_virtual_tx_input(
    psbt: Psbt,
    input_index: usize,
    witness_utxo: TxOut,
) -> Result<Transaction, Error>
Finalize a virtual transaction input using only the authorization data already present in the PSBT input.

This is intended for historical virtual transactions in a unilateral-exit branch. The caller provides the witness_utxo for the input being finalized, and this function materializes either the taproot key-spend witness used by batch-tree internal nodes or a satisfiable taproot script-spend witness used when spending VTXOs.