pub struct OnChainInput { /* private fields */ }Expand description
A UTXO that could have become a VTXO with the help of the Ark server, but is now unilaterally spendable by the original owner.
Implementations
Sourceimpl OnChainInput
impl OnChainInput
pub fn new( boarding_output: BoardingOutput, amount: Amount, outpoint: OutPoint, ) -> Self
pub fn previous_output(&self) -> TxOut