UnilateralExitTree

Struct UnilateralExitTree 

pub struct UnilateralExitTree { /* private fields */ }
The full path from a commitment transaction to a VTXO. The entire path must be published on-chain to execute a unilateral exit with this VTXO.

A branch may contain both batch-tree internal node transactions, which spend their parent via key path, and VTXO spend transactions, which spend a confirmed or pre-confirmed VTXO via script path. We use the word “tree” because a VTXO may come from more than one path, e.g. if its corresponding Ark transaction has more than one input.

Implementations

Source

impl UnilateralExitTree

pub fn new(commitment_txids: Vec<Txid>, virtual_tx_tree: Vec<Vec<Psbt>>) -> Self

pub fn inner(&self) -> &Vec<Vec<Psbt>>

pub fn commitment_txids(&self) -> &[Txid]