VhtlcScript

Struct VhtlcScript 

pub struct VhtlcScript { /* private fields */ }
VHTLC Script builder and manager

This struct creates and manages VHTLC scripts with six different spending paths:

  1. Claim: Receiver reveals preimage (collaborative with server)
  2. Refund: Collaborative refund (all three parties)
  3. Refund without Receiver: Sender refunds after locktime (with server)
  4. Unilateral Claim: Receiver claims after delay (no server needed)
  5. Unilateral Refund: Collaborative unilateral refund after delay
  6. Unilateral Refund without Receiver: Sender unilateral refund after both timeouts

Implementations

Source

impl VhtlcScript

pub fn new(options: VhtlcOptions, network: Network) -> Result<Self, VhtlcError>

Creates a new VHTLC script with the given options

This will validate the options and build the complete taproot tree with all spending paths.

pub fn taproot_spend_info(&self) -> &TaprootSpendInfo

pub fn script_pubkey(&self) -> ScriptBuf

pub fn address(&self) -> ArkAddress

pub fn claim_script(&self) -> ScriptBuf

Creates the claim script where receiver reveals the preimage

Requires: preimage hash verification + receiver signature + server signature

pub fn refund_script(&self) -> ScriptBuf

Creates the collaborative refund script

Requires: sender + receiver + server signatures

pub fn refund_without_receiver_script(&self) -> ScriptBuf

Creates the refund script when receiver is unavailable

Requires: CLTV timeout + sender + server signatures

pub fn unilateral_claim_script(&self) -> ScriptBuf

Creates the unilateral claim script (no server cooperation needed)

Requires: preimage hash verification + CSV delay + receiver signature

pub fn unilateral_refund_script(&self) -> ScriptBuf

Creates the unilateral refund script

Requires: CSV delay + sender + receiver signatures

pub fn unilateral_refund_without_receiver_script(&self) -> ScriptBuf

Creates the unilateral refund script when receiver is unavailable

Requires: CSV delay + sender signature

pub fn get_script_map(&self) -> BTreeMap<String, ScriptBuf>

pub fn tapscripts(self) -> Vec<ScriptBuf>