Re-exports
pub use arknote::ArkNote;pub use boarding_output::BoardingOutput;pub use script::extract_sequence_from_csv_sig_script;pub use unilateral_exit::build_anchor_tx;pub use unilateral_exit::build_unilateral_exit_tree_txids;pub use unilateral_exit::SelectedUtxo;pub use unilateral_exit::UtxoCoinSelection;pub use vtxo::Vtxo;
Modules
- arknote
- ArkNote: a transferable off-chain value token.
- batch
- boarding_
output - coin_
select - conversions
- history
- intent
- script
- send
- server
- Messages exchanged between the client and the Ark server.
- unilateral_
exit - vhtlc
- Virtual Hash Time Lock Contract (VHTLC) implementation for Ark Lightning Swaps.
- vtxo
Structs
- ArkAddress
- Error
- Explorer
Utxo - Information a UTXO that may be extracted from an on-chain explorer.
- TxGraph
- TxGraph
Chunk - Vtxo
List
Constants
- DEFAULT_
DERIVATION_ PATH - UNSPENDABLE_
KEY - VTXO_
CONDITION_ KEY - The byte value corresponds to the string “condition”.
- VTXO_
COSIGNER_ PSBT_ KEY - The cosigner PKs that sign a VTXO TX input are included in the
unknownkey-value map field of that input in the VTXO PSBT. Since theunknownfield can be used for any purpose, we know that a value is a cosigner PK if the corresponding key starts with this prefix. - VTXO_
INPUT_ INDEX - VTXO_
TAPROOT_ KEY - The byte value corresponds to the string “taptree”.
- VTXO_
TREE_ EXPIRY_ PSBT_ KEY - The byte value corresponds to the string “expiry”.
Traits
- Error
Context - A trait for contextualizing error values.