Structs
- Delegate
- A delegate contains all the information necessary for another party to settle VTXOs on behalf of the owner.
- Nonce
Kps - A nonce key pair per batch-tree transaction output that we are a part of in the batch.
- OnChain
Input - A UTXO that is primed to become a VTXO. Alternatively, the owner of this UTXO may decide to spend it into a vanilla UTXO.
Functions
- aggregate_
nonces - Compute the aggregated nonce public key for a transaction in the batch-tree.
- complete_
delegate_ forfeit_ txs - create_
and_ sign_ forfeit_ txs - Build and sign a forfeit transaction per [
VtxoInput] to be used in an upcoming commitment transaction. - create_
asset_ preservation_ packet - Complete the delegated forfeit transactions by adding connector inputs and finalizing them.
- generate_
nonce_ tree - Generate a nonce key pair for each batch-tree transaction output that we are a part of in the batch.
- prepare_
delegate_ psbts - Prepare unsigned intent and forfeit PSBTs for delegate.
- prepare_
delegate_ psbts_ at - Like
prepare_delegate_psbts, but with an explicitvalid_attimestamp. - sign_
batch_ tree_ tx - Use
own_cosigner_kpto sign each batch-tree transaction output that we are a part of, usingour_nonce_kpsto provide our share of each aggregate nonce. - sign_
commitment_ psbt - Sign every input of the
commitment_psbtwhich is in the providedonchain_inputslist. - sign_
delegate_ psbts - Sign delegate PSBTs.