Transaction

Enum Transaction 

pub enum Transaction {
    Boarding {
        txid: Txid,
        amount: Amount,
        confirmed_at: Option<i64>,
    },
    Commitment {
        txid: Txid,
        amount: SignedAmount,
        created_at: i64,
    },
    Ark {
        txid: Txid,
        amount: SignedAmount,
        is_settled: bool,
        created_at: i64,
    },
    Offboard {
        commitment_txid: Txid,
        amount: Amount,
        confirmed_at: Option<i64>,
    },
}

Variants



Boarding

A transaction that transforms a UTXO into a boarding output.

Fields

txid: Txid
amount: Amount

We use Amount because boarding transactions are always incoming i.e. we receive a boarding output.

confirmed_at: Option<i64>


Commitment

A transaction that confirms VTXOs.

Fields

txid: Txid
amount: SignedAmount

We use SignedAmount because commitment transactions may be incoming or outgoing i.e. we can send or receive VTXOs.

created_at: i64


Ark

A transaction that has VTXOs as outputs.

Fields

txid: Txid
amount: SignedAmount

We use SignedAmount because Ark transactions may be incoming or outgoing i.e. we can send or receive VTXOs.

is_settled: bool

An Ark transaction is settled if our outputs in it have been spent. Thus, if we have no outputs in it, it is considered settled too.

created_at: i64


Offboard

A transaction that offboards VTXOs to an onchain output.

Fields

commitment_txid: Txid

The commitment TXID that settles the VTXOs.

amount: Amount

We use Amount because offboarding transactions are always outgoing.

confirmed_at: Option<i64>

Confirmation time of the commitment transaction. This information must be provided by an external source (e.g., esplora).

Implementations

Source

impl Transaction

pub fn created_at(&self) -> Option<i64>

The creation time of the Transaction. This value can be used for sorting.

  • The creation time of a boarding transaction is based on its confirmation time. If it is pending, we return None.

  • The creation time of a commitment transaction is based on the created_at of our VTXO produced by it.

  • The creation time of an Ark transaction is based on the created_at of our VTXO produced by it.

  • The creation time of an offboard transaction is based on its confirmation time. If it is pending, we return None.

pub fn txid(&self) -> Txid