pub fn csv_sig_script(locktime: Sequence, pk: XOnlyPublicKey) -> ScriptBufExpand description
A ScriptBuf allowing the owner of pk to spend after locktime_seconds have passed from
the time the corresponding output was included in a block.
pub fn csv_sig_script(locktime: Sequence, pk: XOnlyPublicKey) -> ScriptBufA ScriptBuf allowing the owner of pk to spend after locktime_seconds have passed from
the time the corresponding output was included in a block.