pub struct VirtualTxOutPoint {Show 13 fields
pub outpoint: OutPoint,
pub created_at: i64,
pub expires_at: i64,
pub amount: Amount,
pub script: ScriptBuf,
pub is_preconfirmed: bool,
pub is_swept: bool,
pub is_unrolled: bool,
pub is_spent: bool,
pub spent_by: Option<Txid>,
pub commitment_txids: Vec<Txid>,
pub settled_by: Option<Txid>,
pub ark_txid: Option<Txid>,
}Fields
outpoint: OutPointcreated_at: i64expires_at: i64amount: Amountscript: ScriptBufis_preconfirmed: boolA pre-confirmed VTXO spends from another VTXO and is not a leaf of the original VTXO tree in a batch.
is_swept: boolis_unrolled: boolis_spent: boolspent_by: Option<Txid>If the VTXO is spent, this field references the checkpoint transaction that actually
spends it. The corresponding Ark transaction is in the ark_txid field.
If the VTXO is renewed, this field references the corresponding forfeit transaction.
commitment_txids: Vec<Txid>The list of commitment transactions that are ancestors to this VTXO.
settled_by: Option<Txid>The commitment TXID onto which this VTXO was forfeited.
ark_txid: Option<Txid>The Ark transaction that spends this VTXO (if we omit the checkpoint transaction).
Implementations
Sourceimpl VirtualTxOutPoint
impl VirtualTxOutPoint
Sourcepub fn is_recoverable(&self, dust: Amount) -> bool
pub fn is_recoverable(&self, dust: Amount) -> bool
Check if a VTXO is recoverable.
Recoverable VTXOs can be settled, but they cannot be sent in an offchain transaction. To settle them, the original VTXO does not need to be forfeited, as the Arkade server already controls it.
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check if a VTXO has expired.
Expired VTXOs can be settled, but they cannot be sent in an offchain transaction. To settle them, the original VTXO must be forfeited.
NOTE: The server’s concept of now may differ from the client’s, so client and server may sometimes disagree on whether a VTXO has expired or not.