pub struct UnilateralExitTree { /* private fields */ }Expand description
The full path from a commitment transaction to a VTXO. The entire path must be published on-chain to execute a unilateral exit with this VTXO.
A branch may contain both batch-tree internal node transactions, which spend their parent via key path, and VTXO spend transactions, which spend a confirmed or pre-confirmed VTXO via script path. We use the word “tree” because a VTXO may come from more than one path, e.g. if its corresponding Ark transaction has more than one input.
Implementations