Vtxo

Struct Vtxo 

pub struct Vtxo { /* private fields */ }
All the information needed to spend a VTXO.

Implementations

Source

impl Vtxo

pub fn new_with_custom_scripts<C>( secp: &Secp256k1<C>, server_forfeit: XOnlyPublicKey, owner: XOnlyPublicKey, scripts: Vec<ScriptBuf>, exit_delay: Sequence, network: Network, ) -> Result<Self, Error>
where C: Verification,

Build a VTXO, by providing all the scripts to be included in the Taproot tree.

The provided scripts must follow the following rules:

  • All unilateral spend paths MUST be timelocked.
  • All other spend paths MUST involve the Ark server’s signature.
pub fn new_with_custom_scripts_and_split_owner_keys<C>( secp: &Secp256k1<C>, server_forfeit: XOnlyPublicKey, owner: XOnlyPublicKey, owner_unilateral_exit: XOnlyPublicKey, scripts: Vec<ScriptBuf>, exit_delay: Sequence, network: Network, ) -> Result<Self, Error>
where C: Verification,

pub fn new_default<C>( secp: &Secp256k1<C>, server_signer: XOnlyPublicKey, owner: XOnlyPublicKey, exit_delay: Sequence, network: Network, ) -> Result<Self, Error>
where C: Verification,

Build a default VTXO.

pub fn new_with_delegator<C>( secp: &Secp256k1<C>, server_signer: XOnlyPublicKey, owner: XOnlyPublicKey, delegator: XOnlyPublicKey, exit_delay: Sequence, network: Network, ) -> Result<Self, Error>
where C: Verification,

Build a VTXO with a delegate spending path.

This creates a 3-leaf Taproot tree:

  1. Forfeit: 2-of-2 multisig (server + owner)
  2. Exit: CSV-timelocked owner signature
  3. Delegate: 3-of-3 multisig (owner + delegator + server)

The delegate path allows a third-party delegator service to cooperate with the owner and the server to renew VTXOs before they expire.

pub fn script_pubkey(&self) -> ScriptBuf

pub fn address(&self) -> &Address

pub fn owner_pk(&self) -> XOnlyPublicKey

pub fn server_pk(&self) -> XOnlyPublicKey

pub fn delegator_pk(&self) -> Option<XOnlyPublicKey>

pub fn exit_delay(&self) -> Sequence

pub fn to_ark_address(&self) -> ArkAddress

pub fn get_spend_info(&self, script: ScriptBuf) -> Result<ControlBlock, Error>

The spend info of an arbitrary branch of a VTXO.

pub fn forfeit_spend_info(&self) -> Result<(ScriptBuf, ControlBlock), Error>

The spend info for the forfeit branch of a default VTXO.

This method can fail because Vtxos constructed with the method Vtxo::new_with_custom_scripts may not contain this script exactly.

pub fn exit_spend_info(&self) -> Result<(ScriptBuf, ControlBlock), Error>

The spend info for the unilateral exit branch of a default VTXO.

This method can fail because Vtxos constructed with the method Vtxo::new_with_custom_scripts may not contain this script exactly.

pub fn delegate_spend_info(&self) -> Result<(ScriptBuf, ControlBlock), Error>

The spend info for the delegate branch of a VTXO constructed with Vtxo::new_with_delegator.

Returns an error if the VTXO was not built with a delegator.

pub fn tapscripts(&self) -> Vec<ScriptBuf>

pub fn can_be_claimed_unilaterally_by_owner( &self, now: Duration, confirmation_blocktime: Duration, confirmations: u64, ) -> bool

Whether the VTXO can be claimed unilaterally by the owner or not, given the confirmation_blocktime of the transaction that included this VTXO as an output.